#
# spec file for package ms-gsl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ms-gsl
Version:        4.2.0
Release:        1.1
Summary:        Guidelines Support Library
License:        MIT
URL:            https://github.com/Microsoft/GSL
Source:         %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  git-core
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(gtest)
BuildArch:      noarch

%description
The Guidelines Support Library (GSL) contains functions and types
that are suggested for use by the C++ Core Guidelines maintained by
the Standard C++ Foundation. This repo contains Microsoft's
implementation of GSL. The entire implementation is provided inline
in the headers under the gsl directory. The implementation generally
assumes a platform that implements C++14 support. While some types
have been broken out into their own headers (e.g. gsl/span), it is
simplest to just include gsl/gsl and gain access to the entire
library.

%package devel
Summary:        Development files for %{name}

%description devel
%{summary}.

%prep
%autosetup -n GSL-%{version}

%build
%cmake \
  -DGSL_TEST=ON \
  -DCMAKE_BUILD_TYPE=Release
%cmake_build

%install
%cmake_install

%check
%ctest

%files devel
%license LICENSE
%doc README.md ThirdPartyNotices.txt CONTRIBUTING.md
%{_datadir}/cmake/Microsoft.GSL/
%{_includedir}/gsl/

%changelog
* Sun Mar  2 2025 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream version 4.2.0
  * New Features:
  - Added gsl::swap for safely swapping gsl::not_null pointers (#1160)
  - Introduced element_type member type to gsl::not_null for better type
    trait consistency (#1196)
  - Added support for strict_not_null with unique_ptr (#1179)
  - Added comprehensive test suite for gsl::span including empty span,
    conversion, and comparison tests (#1189)
  * Performance Improvements:
  - Significantly improved span_iterator performance with Clang compiler,
    reducing overhead by up to 20x (#1166)
  * Bug Fixes:
  - Fixed GCC-specific bug with list initialization of const
    references (#1175)
  - Fixed SFINAE implementation in gsl::owner (#1174)
  - Fixed issues with std::enable_if usage throughout the codebase (#1177)
  - Modified include directives to use explicit "gsl/" prefix to prevent
    header conflicts (#1184)
  - Changed include directives to use relative paths to comply with
    CppCoreGuideline SF.12 (#1194)
  * Deprecated Features:
  - Removed deprecated string_span feature (#1185)
  - Marked the following features as deprecated as they are now in the
    C++ standard:
  * gsl::unique_ptr
  * gsl::shared_ptr
  * gsl::byte (since C++17)
  * gsl::joining_thread
* Thu Dec 26 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding '_service' file for tarball download
* Mon Oct 21 2024 Scott Bradnick <scott.bradnick@suse.com>
- Looks like v4.1.0 was [re]released? List of changes under
  https://github.com/microsoft/GSL/releases/tag/v4.1.0 is quite different
  * Grabbed tarball from this [re]release.
* Thu Oct 17 2024 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream version 4.1.0
  * quoted form of #include when GSL includes GSL files by @beinhaerter
    in #1030
  * Suppress reserved identifier warning by @dmitrykobets-msft in #1041
  * Make gsl::span's iterators use the contiguous_iterator concept by
    @dmitrykobets-msft in #1035
  * Suppress -Wfloat-equal warning by @dmitrykobets-msft in #1043
  * gsl/narrow should include by @TheJCAB in #1044
  * Many other changes, see:
    https://github.com/microsoft/GSL/releases/tag/v4.1.0
* Thu May 25 2023 Scott Bradnick <scott.bradnick@suse.com>
- Enabling testing suite
* Tue May 23 2023 Jan Engelhardt <jengelh@inai.de>
- Trim duplicate autogenerated cmake() from ms-gsl-devel.
- Delete -static provide, it's not provided.
* Sun May 14 2023 Scott Bradnick <scott.bradnick@suse.com>
- Initial version from upstream
  * Pulled, in general, from OBS://home:Dead_Mozay:telegram/ms-gsl
